pub struct CryptService { /* private fields */ }Implementations
Sourceimpl CryptService
impl CryptService
Sourcepub fn new(
raw_metadata_key: &[u8],
raw_data_key: &[u8],
inline_crypto_proxy: Option<DeviceSynchronousProxy>,
) -> Self
pub fn new( raw_metadata_key: &[u8], raw_data_key: &[u8], inline_crypto_proxy: Option<DeviceSynchronousProxy>, ) -> Self
Creates a new crypt service that supports Starnix user volumes.
Sourcepub fn contains_key(&self, key: EncryptionKeyId) -> bool
pub fn contains_key(&self, key: EncryptionKeyId) -> bool
Returns true if key is registered with the service.
Sourcepub fn get_users_for_key(&self, key: EncryptionKeyId) -> Option<Vec<u32>>
pub fn get_users_for_key(&self, key: EncryptionKeyId) -> Option<Vec<u32>>
Returns the users registered for key.
Sourcepub fn add_wrapping_key(
&self,
raw_key: &[u8],
uid: u32,
) -> Result<EncryptionKeyId, Errno>
pub fn add_wrapping_key( &self, raw_key: &[u8], uid: u32, ) -> Result<EncryptionKeyId, Errno>
Adds the specified wrapping key for user uid.
Sourcepub async fn handle_connection(
&self,
stream: CryptRequestStream,
) -> Result<(), Error>
pub async fn handle_connection( &self, stream: CryptRequestStream, ) -> Result<(), Error>
Serves crypt requests.
Sourcepub fn forget_wrapping_key(
&self,
wrapping_key_id: EncryptionKeyId,
uid: u32,
) -> Result<(), Errno>
pub fn forget_wrapping_key( &self, wrapping_key_id: EncryptionKeyId, uid: u32, ) -> Result<(), Errno>
Removes wrapping_key_id for user uid.
pub fn set_uuid(&self, uuid: [u8; 16])